<?php

namespace Drupal\commerce_iats;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * CommerceIats payment class.
 */
class CommerceIats {

  /**
   * The configuration factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * CommerceIats constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory service.
   * @param \Drupal\Core\Session\AccountInterface $currentUser
   *   The configuration factory service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, AccountInterface $currentUser) {
    $this->currentUser = $currentUser;
    $this->configFactory = $configFactory;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('current_user')

    );
  }

  /**
   * Gets a vault ID for a user.
   *
   * @param \Drupal\Core\Session\AccountInterface|null $account
   *   The user account, optional. Defaults to the current user.
   *
   * @return string
   *   A vault ID for the user.
   */
  public function getUserVaultId(AccountInterface $account = NULL) {
    if (!$account) {
      $account = $this->currentUser;
    }
    return 'drupal:' . $this->getVaultIdPrefix() . ':' . $account->id();
  }

  /**
   * Gets the site's vault ID prefix.
   *
   * @return string
   *   The vault prefix.
   */
  public function getVaultIdPrefix() {
    return $this->configFactory
      ->get('commerce_iats.settings')
      ->get('vault_id_prefix');
  }

  /**
   * Sets a vault ID prefix for the site.
   *
   * @param string|null $prefix
   *   A prefix to use for vault IDs, or NULL to create a random prefix.
   */
  public function setVaultIdPrefix($prefix = NULL) {
    if ($this->getVaultIdPrefix()) {
      return;
    }

    // @todo remove the if version_compare once the module stops supporting Drupal8
    // @todo use dependency injections instead of \Drupal global
    if (!$prefix) {
      if (version_compare(\Drupal::VERSION, 9.1, '>=')) {
        // 9.1+
        $prefix = \Drupal::service('password_generator')->generate();
      }
      else {
        $prefix = user_password();
      }
    }

    $this->configFactory
      ->getEditable('commerce_iats.settings')
      ->set('vault_id_prefix', $prefix)
      ->save();
  }

}
